<?php

/**
 * This file contains \QUI\Menu\SidebarDropDownMenu
 */

namespace QUI\Menu;

use QUI;
use QUI\Projects\Site\Utils;

/**
 * Class SidebarDropDownMenu
 * Creates on Sidebar Drop Down Menu
 *
 * @package QUI\Menu
 * @author www.pcsg.de (Michael Danielczok, Henning Leutz)
 */
class SidebarDropDownMenu extends QUI\Control
{
    /**
     * @param array $attributes
     */
    public function __construct($attributes = array())
    {
        // defaults values
        $this->setAttributes(array(
            'startId'    => 1, // id or site link
            'parentLink' => false,
            'levels'     => 0,
            'listType'   => 'fontAwesome',
            'homeIcon'   => 'fa-home',
            'listIcon'   => 'fa-angle-right',
            'levelIcon'  => 'fa-angle-double-down',
            'qui-class'  => 'package/quiqqer/menu/bin/SidebarDropDownMenu'
        ));

        parent::__construct($attributes);

        $this->addCSSFile(
            dirname(__FILE__) . '/SidebarDropDownMenu.css'
        );

        $this->setAttribute('class', 'quiqqer-sidebar-dropdown-navigation');
    }

    /**
     * (non-PHPdoc)
     *
     * @see \QUI\Control::create()
     */
    public function getBody()
    {
        $Engine   = QUI::getTemplateManager()->getEngine();
        $Project  = $this->getProject();
        $activeId = false;

        // start
        try {
            $startId = $this->getAttribute('startId');

            if (Utils::isSiteLink($startId)) {
                $Site = Utils::getSiteByLink($startId);
            } else {
                $Site = $Project->get((int)$startId);
            }
        } catch (QUI\Exception $Exception) {
            QUI\System\Log::addWarning($Exception->getMessage());

            return '';
        }


        if ($Site->getId() != 1) {
            $FirstPage = $Site->getParent();
        } else {
            $FirstPage = $this->getProject()->firstChild();
        }


        // active site
        $ActiveSite = QUI::getRewrite()->getSite();

        if ($ActiveSite && $ActiveSite->getProject() == $Project) {
            $activeId = $ActiveSite->getId();
        }

        // settings
        $levels = (int)$this->getAttribute('levels');

        if ($levels <= 0 || $this->getAttribute('levels') === false) {
            $levels = false;
        }

        $Engine->assign(array(
            'this'        => $this,
            'Project'     => $this->getProject(),
            'Site'        => $Site,
            'FirstPage'   => $FirstPage,
            'listType'    => $this->getAttribute('listType'),
            'parentLink'  => $this->getAttribute('parentLink'),
            'activeId'    => $activeId,
            'navTemplate' => dirname(__FILE__) . '/SidebarDropDownMenu.html',
            'levels'      => $levels,
            'Rewrite'     => QUI::getRewrite(),
            'parentIcon'  => $this->getAttribute('parentIcon'),
            'listIcon'    => $this->getAttribute('listIcon'),
            'levelIcon'   => $this->getAttribute('levelIcon')
        ));

        $html = $Engine->fetch(dirname(__FILE__) . '/SidebarDropDownMenu.html');
        $html = '<nav>' . $html . '</nav>';

        return $html;
    }
}
